@@ -8,7 +8,7 @@
 # This example generates some Chinese from a file with BIG5 encoded text.
 #
 #
-# reverse(''), September 2004, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2020, John McNamara, jmcnamara@cpan.org
 #
 
 use strict;
@@ -36,6 +36,7 @@ while ( <FH> ) {
     $worksheet->write( $row++, 0, $_ );
 }
 
+$workbook->close();
 
 __END__
 
